@@ -1,7 +1,9 @@
 #!/usr/bin/env perl
+use v5.18;
 use strict;
 use utf8;
 use NewsExtractor;
+use Encode qw< encode_utf8 >;
 use File::Slurp qw< write_file >;
 
 sub try_extract {
@@ -11,22 +13,43 @@ sub try_extract {
     return 1 if $err;
     ($err, my $article) = $y->parse;
     return 2 if $err;
-    return 0;
+    return (0, $article);
+}
+
+sub checkmark {
+    my ($v) = @_;
+    if ($v && $v ne '') {
+        return "\x{02713}"; # CHECK MARK
+    } else {
+        return "\x{0274C}"; # CROSS MARK
+    }
 }
 
 ## main
 my (@urls_err_download, @urls_err_parse, @urls_good);
 my ($count_all, $count_success, $count_err_download, $count_err_parse) = (0,0,0,0);
+
+say encode_utf8(join("\t", "Headline", "Dateline", "Journalist", "Body", "URL"));
+
 while(<>) {
     chomp;
     my $url = $_;
 
     $count_all++;
-    my $err = try_extract($url);
+    my ($err, $article) = try_extract($url);
 
     if ($err == 0) {
         $count_success++;
         push @urls_good, $url;
+        say encode_utf8(
+            join("\t",
+                 checkmark($article->headline),
+                 checkmark($article->dateline),
+                 checkmark($article->journalist),
+                 checkmark($article->article_body),
+                 $url,
+             )
+         );
     } elsif ($err == 1) {
         $count_err_download++;
         push @urls_err_download, $url;
@@ -34,8 +57,6 @@ while(<>) {
         $count_err_parse++;
         push @urls_err_parse, $url;
     }
-
-    printf "%8d/%-8d - %8d,%8d: %s - %s\n", $count_success, $count_all, $count_err_download, $count_err_parse, ($err ? "(x)" : "(o)"), $url;
 }
 
 printf "%8d/%-8d\n", $count_success, $count_all;
